.. Copyright (C) 2018 Branko Majic

   This file is part of Gimmecert documentation.

   This work is licensed under the Creative Commons Attribution-ShareAlike 3.0
   Unported License. To view a copy of this license, visit
   http://creativecommons.org/licenses/by-sa/3.0/ or send a letter to Creative
   Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.


Installation
============

Gimmecert can be easily installed using ``pip``. Before installing it,
make sure the following requirements have been met:

- You are running *Python 3.5+*.

In order to install latest stable release of *Gimmecert* using *pip*, run the
following command::

  pip install gimmecert

In order to install the latest development version of Gimmecert from
git repository, use one of the following commands::

  pip install -e git+https://code.majic.rs/gimmecert#egg=gimmecert
  pip install -e git+https://github.com/azaghal/gimmecert#egg=gimmecert
